-- admin table - Queue for admin tasks sent from front-end for back-end processing.
-- $Id: admin.sql,v 1.6 2007/10/12 05:31:41 maxbaker Exp $ 

DROP TABLE admin;
DROP SEQUENCE admin_job_seq;

CREATE TABLE admin (
    job         serial,
    entered     TIMESTAMP DEFAULT now(),
    started     TIMESTAMP,
    finished    TIMESTAMP,
    device      inet,
    port        text,
    action      text, -- delete, delete+nodes, macsuck, arpnip, refresh, vlan
    subaction   text, -- free field to be used for each action
    status      text, -- queued, running, done, error, del
    username    text,
    userip      inet,
    log         text,
    debug       boolean
                   );

CREATE INDEX idx_admin_entered ON admin(entered);
CREATE INDEX idx_admin_status  ON admin(status);
CREATE INDEX idx_admin_action  ON admin(action);
-- $Id: device.sql,v 1.8 2007/01/05 19:42:24 fenner Exp $

DROP TABLE device;

CREATE TABLE device (
    ip           inet PRIMARY KEY,
    creation     TIMESTAMP DEFAULT now(),
    dns          text,
    description  text,
    uptime       bigint,
    contact      text,
    name         text,
    location     text,
    layers       varchar(8),
    ports        integer,
    mac          macaddr,
    serial       text,
    model        text,
    ps1_type     text,
    ps2_type     text,
    ps1_status   text,
    ps2_status   text,
    fan          text,
    slots        integer,
    vendor       text,      
    os           text,
    os_ver       text,
    log          text,      -- HP Devices can store their log in here.
    snmp_ver     integer,   -- Holds the SNMP Version of device 
    snmp_comm    text,      -- Holds the SNMP Community String
    snmp_class   text,      -- Holds SNMP::Info class for debugging
    vtp_domain   text,
    last_discover TIMESTAMP,
    last_macsuck  TIMESTAMP,
    last_arpnip   TIMESTAMP
);

-- Indexing for speed-ups
CREATE INDEX idx_device_dns    ON device(dns);
CREATE INDEX idx_device_layers ON device(layers);
CREATE INDEX idx_device_vendor ON device(vendor);
CREATE INDEX idx_device_model  ON device(model);
-- $Id: device_ip.sql,v 1.3 2007/01/05 19:42:24 fenner Exp $

DROP TABLE device_ip;

CREATE TABLE device_ip (
    ip          inet,
    alias       inet,
    subnet      cidr,
    port        text,
    dns         text,
    creation    TIMESTAMP DEFAULT now(),
    PRIMARY KEY(ip,alias)
);

-- Indexing for speed ups
CREATE INDEX idx_device_ip_ip      ON device_ip(ip);
CREATE INDEX idx_device_ip_alias   ON device_ip(alias);
CREATE INDEX idx_device_ip_ip_port ON device_ip(ip,port);
-- $Id: device_module.sql,v 1.2 2009/03/06 22:07:34 fenner Exp $

DROP TABLE device_module;

CREATE TABLE device_module (
    ip            inet not null,
    index         integer,
    description   text,
    type          text,
    parent        integer,
    name          text,
    class         text,
    pos           integer,
    hw_ver        text,
    fw_ver        text,
    sw_ver        text,
    serial        text,
    model         text,
    fru           boolean,
    creation      TIMESTAMP DEFAULT now(),
    last_discover TIMESTAMP,
    PRIMARY KEY(ip,index)
    );
-- $Id: device_port.sql,v 1.7 2007/07/18 16:21:21 fenner Exp $

DROP TABLE device_port;

CREATE TABLE device_port (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    creation    TIMESTAMP DEFAULT now(),
    descr       text,   -- Description of Port 
    up          text,   -- Current Link Status
    up_admin    text,   -- Admin Link Status
    type        text,   -- Description of Port Media Type
    duplex      text,   -- Current Duplex Setting
    duplex_admin text,  -- Admin Duplex Setting
    speed       text, 
    name        text,   -- Human Set name
    mac         macaddr,-- MAC of the switch port
    mtu         integer,
    stp         text,   -- Spanning Tree Protocol Status
    remote_ip   inet,   -- Neighboring device connected to
    remote_port text,   -- Neighboring port connected to
    remote_type text,   -- Type of device connected to
    remote_id   text,   -- remote ID string of neighbor
    vlan        text,   -- VLAN port connected to
    pvid        integer,-- PVID for incoming untagged packets
    lastchange  bigint, -- Last time the port went up or down
    PRIMARY KEY(port,ip) 
);

CREATE INDEX idx_device_port_ip ON device_port(ip);
CREATE INDEX idx_device_port_remote_ip ON device_port(remote_ip);
-- For the duplex mismatch finder :
CREATE INDEX idx_device_port_ip_port_duplex ON device_port(ip,port,duplex);
CREATE INDEX idx_device_port_ip_up_admin ON device_port(ip,up_admin);
CREATE INDEX idx_device_port_mac ON device_port(mac);
-- $Id: device_port_log.sql,v 1.4 2003/03/21 00:40:01 max Exp $

DROP TABLE device_port_log;
DROP SEQUENCE device_port_log_id_seq;

CREATE TABLE device_port_log (
    id          serial, 
    ip          inet,
    port        text,
    reason      text,
    log         text, 
    username    text,   -- user is a reserved word
    userip      inet,
    action      text,
    creation    TIMESTAMP DEFAULT now()
                             );

CREATE INDEX idx_device_port_log_1 ON device_port_log(ip,port);
CREATE INDEX idx_device_port_log_user ON device_port_log(username);
-- $Id: device_port_power.sql,v 1.1 2007/10/11 23:44:26 fenner Exp $

DROP TABLE device_port_power;

CREATE TABLE device_port_power (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    module      integer,-- Module from PowerEthernet index
    admin       text,   -- Admin power status
    status      text,   -- Detected power status
    class       text,   -- Detected class
    PRIMARY KEY(port,ip)
);
-- $Id: device_port_ssid.sql,v 1.3 2009/04/13 01:00:27 olly_g Exp $

DROP TABLE device_port_ssid;

CREATE TABLE device_port_ssid (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    ssid        text,   -- An SSID that is valid on this port.
    broadcast   boolean -- Is it broadcast?
);

CREATE INDEX idx_device_port_ssid_ip_port ON device_port_ssid(ip,port);
-- $Id: device_port_vlan.sql,v 1.1 2007/07/18 16:21:21 fenner Exp $

DROP TABLE device_port_vlan;

CREATE TABLE device_port_vlan (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    vlan        integer, -- VLAN ID
    native      boolean not null default false, -- native or trunked
    creation    TIMESTAMP DEFAULT now(),
    last_discover TIMESTAMP DEFAULT now(),
    PRIMARY KEY(ip,port,vlan)
);
-- $Id: device_port_wireless.sql,v 1.1 2009/03/24 18:08:03 fenner Exp $

DROP TABLE device_port_wireless;

CREATE TABLE device_port_wireless (
    ip          inet,   -- ip of device
    port        text,   -- Unique identifier of Physical Port Name
    channel     integer,-- 802.11 channel number
    power       integer -- transmit power in mw
);

CREATE INDEX idx_device_port_wireless_ip_port ON device_port_wireless(ip,port);
-- $Id: device_power.sql,v 1.1 2007/10/11 23:44:26 fenner Exp $

DROP TABLE device_power;

CREATE TABLE device_power (
    ip          inet,   -- ip of device
    module      integer,-- Module from PowerEthernet index
    power       integer,-- nominal power of the PSE expressed in Watts
    status      text,   -- The operational status
    PRIMARY KEY(ip,module)
);
-- $Id: device_vlan.sql,v 1.1 2007/07/18 16:21:21 fenner Exp $

DROP TABLE device_vlan;

CREATE TABLE device_vlan (
    ip          inet,   -- ip of device
    vlan        integer, -- VLAN ID
    description text,   -- VLAN description
    creation    TIMESTAMP DEFAULT now(),
    last_discover TIMESTAMP DEFAULT now(),
    PRIMARY KEY(ip,vlan)
);
-- $Id: log.sql,v 1.3 2004/11/09 20:06:16 maxbaker Exp $

DROP TABLE log;
DROP SEQUENCE log_id_seq;

CREATE TABLE log (
    id          serial,
    creation    TIMESTAMP DEFAULT now(),
    class       text,
    entry       text,
    logfile     text
);
-- $Id: node.sql,v 1.4 2006/04/04 22:55:52 fenner Exp $

DROP TABLE node;

CREATE TABLE node (
    mac         macaddr,
    switch      inet,
    port        text,
    active      boolean,
    oui         varchar(8),  -- fe:9a:57
    time_first  timestamp default now(),
    time_recent timestamp default now(),
    time_last   timestamp default now(),
    PRIMARY KEY(mac,switch,port) 
);

-- Indexes speed things up a LOT
CREATE INDEX idx_node_switch_port_active ON node(switch,port,active);
CREATE INDEX idx_node_switch_port ON node(switch,port);
CREATE INDEX idx_node_switch      ON node(switch);
CREATE INDEX idx_node_mac         ON node(mac);
CREATE INDEX idx_node_mac_active  ON node(mac,active);
-- CREATE INDEX idx_node_oui         ON node(oui);
-- $Id: node_ip.sql,v 1.3 2003/02/18 19:05:12 max Exp $

DROP TABLE node_ip;

CREATE TABLE node_ip (
    mac         macaddr,
    ip          inet,
    active      boolean,
    time_first  timestamp default now(),
    time_last   timestamp default now(),
    PRIMARY KEY(mac,ip)
);

-- Indexing speed ups.
CREATE INDEX idx_node_ip_ip          ON node_ip(ip);
CREATE INDEX idx_node_ip_mac         ON node_ip(mac);
CREATE INDEX idx_node_ip_mac_active  ON node_ip(mac,active);
-- $Id: node_monitor.sql,v 1.1 2009/03/27 07:19:03 fenner Exp $

DROP TABLE node_monitor;

CREATE TABLE node_monitor (
    mac         macaddr,
    active      boolean,
    why         text,
    cc          text,
    date        TIMESTAMP DEFAULT now(),
    PRIMARY KEY(mac)
);
-- $Id: node_nbt.sql,v 1.2 2004/11/01 05:02:43 maxbaker Exp $
-- node_nbt - Hold Netbios information for each node.

DROP TABLE node_nbt;

CREATE TABLE node_nbt (
    mac         macaddr PRIMARY KEY,
    ip          inet,
    nbname      text,
    domain      text,
    server      boolean,
    nbuser      text,
    active      boolean,    -- do we need this still?
    time_first  timestamp default now(),
    time_last   timestamp default now()
);

-- Indexing speed ups.
CREATE INDEX idx_node_nbt_mac         ON node_nbt(mac);
CREATE INDEX idx_node_nbt_nbname      ON node_nbt(nbname);
CREATE INDEX idx_node_nbt_domain      ON node_nbt(domain);
CREATE INDEX idx_node_nbt_mac_active  ON node_nbt(mac,active);
-- $Id: node_wireless.sql,v 1.2 2009/03/25 22:10:07 fenner Exp $

DROP TABLE node_wireless;

CREATE TABLE node_wireless (
    mac         macaddr,
    uptime      integer,
    maxrate     integer, -- can be 0.5 but we ignore that for now
    txrate      integer, -- can be 0.5 but we ignore that for now
    sigstrength integer, -- signal strength (-db)
    sigqual     integer, -- signal quality
    rxpkt       integer, -- received packets
    txpkt       integer, -- transmitted packets
    rxbyte      bigint,  -- received bytes
    txbyte      bigint,  -- transmitted bytes
    time_last   timestamp default now(),
    PRIMARY KEY(mac)
);

-- $Id: oui.sql,v 1.3 2003/03/21 00:40:51 max Exp $

DROP TABLE oui;

CREATE TABLE oui (
    oui         varchar(8) PRIMARY KEY,
    company     text
);

-- process table - Queue to coordinate between processes in multi-process mode.
-- $Id: process.sql,v 1.2 2009/01/15 03:22:27 jeneric Exp $

DROP TABLE process;
CREATE TABLE process (
    controller  integer not null, -- pid of controlling process
    device      inet not null,
    action      text not null,    -- arpnip, macsuck, nbtstat, discover
    status      text,    	  -- queued, running, skipped, done, error, timeout, nocdp, nosnmp
    count       integer,
    creation    TIMESTAMP DEFAULT now()
    );
-- $Id: sessions.sql,v 1.3 2003/02/27 18:46:31 max Exp $

DROP TABLE sessions;

CREATE TABLE sessions (
    id          char(32) NOT NULL PRIMARY KEY,
    creation    TIMESTAMP DEFAULT now(),
    a_session   text
                       );
-- $Id: subnets.sql,v 1.1 2005/03/21 03:47:48 jeneric Exp $

DROP TABLE subnets;

CREATE TABLE subnets (
    net cidr NOT NULL,
    creation timestamp default now(),
    last_discover timestamp default now(),
    PRIMARY KEY(net)
);
-- $Id: user_log.sql,v 1.1 2004/09/25 03:54:32 maxbaker Exp $
-- This table logs login and logout / change requests for users

DROP TABLE user_log;
DROP SEQUENCE user_log_entry_seq;

CREATE TABLE user_log (
    entry           serial,
    username        varchar(50),
    userip          inet,
    event           text,
    details         text,
    creation        TIMESTAMP DEFAULT now()
                      );
-- $Id: users.sql,v 1.4 2007/01/25 03:18:52 jeneric Exp $

DROP TABLE users;

CREATE TABLE users (
    username        varchar(50) PRIMARY KEY,
    password        text,   -- md5 
    creation        TIMESTAMP DEFAULT now(),
    last_on         TIMESTAMP,
    port_control    boolean DEFAULT false,
    ldap            boolean DEFAULT false,
    admin           boolean DEFAULT false,
    fullname        text,
    note            text
                    );
